Fetch a single named option from the active ksTFL settings. This is a
convenience wrapper around tfl_get_options() that returns one element or
throws a friendly error if the option does not exist.
Fetch a single named option from the active ksTFL settings. This is a
convenience wrapper around tfl_get_options() that returns one element or
throws a friendly error if the option does not exist.